# -*- mode: rpm-spec ; mode: font-lock -*-

Summary: Library providing specific CCP4 functionality 
Name: gpp4
Version: 1.3.1
Release: alt1_4
License: LGPLv2
Group: System/Libraries
URL: https://launchpad.net/gpp4
Source0: http://launchpad.net/gpp4/1.3/%{version}/+download/%{name}-%{version}.tar.gz
BuildRequires: doxygen
BuildRequires: mmdb-devel
BuildRequires: gcc-fortran
Source44: import.info

%description

The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

The library contains several subcomponents: 
  * CMTZ library -- Contains a variety of functions for manipulating 
    the data structure, for example adding crystals, datasets or columns. 
    The data structure can be dumped to an output MTZ data file.
  * CMAP library -- Functions defining the C-level API for accessing 
    CCP4 map files.
  * CSYM library -- a collection of functions centred around a data file 
    syminfo.lib which is auto-generated from sgtbx (the Space Group Toolbox 
    of cctbx).
  * CCP4 utility library -- many utility functions which either give 
    specific CCP4 or platform independent functionality.
  * CCP4 Parser library -- provides CCP4-style parsing, as used for 
    processing keywords of CCP4 programs, MTZ header records, etc.
  * CCP4 resizable arrays -- defines an object and methods which looks 
    just like a simple C array, but can be resized at will without 
    incurring excessive overheads.

This package contains the shared library components needed for programs
that have been compiled with the gpp4 library. 

%package devel
Summary: Header files and library for developing free CCP4 programs
Requires: %{name} = %{version}-%{release}
Group: Development/C

%description devel
The CCP4 software suite is based around a library of routines which
cover common tasks, such as file opening, parsing keyworded input,
reading and writing of standard data formats, applying symmetry
operations, etc. Programs in the suite call these routines which, as
well as saving the programmer some effort, ensure that the varied
programs in the suite have a similar look-and-feel.

This package contains libraries and header files needed for program
development.

%prep
%setup -q

%build
%configure --disable-static
# die rpath, die.
sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' libtool
sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' libtool
make %{?_smp_mflags}
doxygen

%install
make install DESTDIR=$RPM_BUILD_ROOT INSTALL='install -p'

# remove unpackaged files from the buildroot
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la

%files
%doc README COPYING NEWS AUTHORS
%{_datadir}/gpp4/
%{_libdir}/libgpp4.so.0
%{_libdir}/libgpp4.so.0.0.0
%{_libdir}/libgpp4f.so.0
%{_libdir}/libgpp4f.so.0.0.0

%files devel
%doc doc/html
%{_includedir}/gpp4
%{_libdir}/libgpp4.so
%{_libdir}/libgpp4f.so
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/pkgconfig/%{name}f.pc

%changelog
* Wed Mar 13 2013 Igor Vlasenko <viy@altlinux.ru> 1.3.1-alt1_4
- update to new release by fcimport

* Wed Jan 16 2013 Igor Vlasenko <viy@altlinux.ru> 1.3.1-alt1_3
- initial fc import

